API reference
=============

.. autofunction:: audio_purifier.purify

.. autofunction:: audio_purifier.purify_and_export

Vad options
-----------
.. autoclass:: audio_purifier.VadOptions
    :members:
    :no-index:

Utils
----------
.. autofunction:: audio_purifier.preload_models
